.. automodule:: sortedcontainers.sortedset


SortedSet
.........

.. autoclass:: sortedcontainers.SortedSet
   :show-inheritance:

   .. automethod:: __init__
   .. autoattribute:: key
   .. automethod:: __contains__
   .. automethod:: __iter__
   .. automethod:: __len__
   .. automethod:: add
   .. automethod:: discard
   .. automethod:: __getitem__
   .. automethod:: __delitem__
   .. automethod:: __reversed__
   .. automethod:: clear
   .. automethod:: pop
   .. automethod:: remove
   .. automethod:: difference
   .. automethod:: difference_update
   .. automethod:: intersection
   .. automethod:: intersection_update
   .. automethod:: symmetric_difference
   .. automethod:: symmetric_difference_update
   .. automethod:: union
   .. automethod:: update
   .. automethod:: copy
   .. automethod:: count
   .. automethod:: __repr__
   .. automethod:: _check
